@@ -1,14 +1,14 @@
-# test_WFSClient_v2_0_0.R
+# test_WFSClient_v1_0_0.R
 # Author: Emmanuel Blondel <emmanuel.blondel1@gmail.com>
 #
-# Description: Integration tests for WFS Client version 2.0.0
+# Description: Integration tests for WFS Client version 1.0.0
 #=======================
 require(ows4R, quietly = TRUE)
 require(testthat)
 context("WFS")
 
-test_that("WFS 2.0.0",{
-  wfs <- WFSClient$new("http://localhost:8080/geoserver/wfs", "2.0.0", logger = "INFO")
+test_that("WFS 1.0.0",{
+  wfs <- WFSClient$new("http://localhost:8080/geoserver/wfs", "1.0.0", logger = "DEBUG")
   expect_is(wfs, "WFSClient")
   caps <- wfs$getCapabilities()
   expect_is(caps, "WFSCapabilities")
@@ -19,4 +19,4 @@ test_that("WFS 2.0.0",{
   ft.sp <- ft$getFeatures()
   expect_is(ft.sp, "sf")
   expect_is(ft.sp, "data.frame")
-})
\ No newline at end of file
+})
